# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.organizationmanager.v1.idp.application.saml import application_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_idp_dot_application_dot_saml_dot_application__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRyandex/cloud/organizationmanager/v1/idp/application/saml/application_service.proto\x12\x38yandex.cloud.organizationmanager.v1.idp.application.saml\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1aJyandex/cloud/organizationmanager/v1/idp/application/saml/application.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x15GetApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9b\x01\n\x17ListApplicationsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\x90\x01\n\x18ListApplicationsResponse\x12[\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32\x45.yandex.cloud.organizationmanager.v1.idp.application.saml.Application\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9e\x06\n\x18\x43reateApplicationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x35\n\x04name\x18\x02 \x01(\tB\'\xe8\xc7\x31\x01\xf2\xc7\x31\x1f[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xab\x01\n\x06labels\x18\x04 \x03(\x0b\x32^.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateApplicationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x63\n\x10service_provider\x18\x05 \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12i\n\x11security_settings\x18\x06 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettingsSpec\x12i\n\x11\x61ttribute_mapping\x18\x07 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMappingSpec\x12l\n\x15group_claims_settings\x18\x08 \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x14SecuritySettingsSpec\x12p\n\x0esignature_mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings.SignatureMode\"k\n\nNameIdSpec\x12]\n\x06\x66ormat\x18\x01 \x01(\x0e\x32G.yandex.cloud.organizationmanager.v1.idp.application.saml.NameId.FormatB\x04\xe8\xc7\x31\x01\"\xd6\x01\n\x14\x41ttributeMappingSpec\x12[\n\x07name_id\x18\x01 \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.NameIdSpecB\x04\xe8\xc7\x31\x01\x12\x61\n\nattributes\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeB\x08\x82\xc8\x31\x04<=50\"3\n\x19\x43reateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"\xc7\x06\n\x18UpdateApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\xab\x01\n\x06labels\x18\x05 \x03(\x0b\x32^.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateApplicationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x12\x63\n\x10service_provider\x18\x06 \x01(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.ServiceProvider\x12\x65\n\x11security_settings\x18\x07 \x01(\x0b\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.SecuritySettings\x12i\n\x11\x61ttribute_mapping\x18\x08 \x01(\x0b\x32N.yandex.cloud.organizationmanager.v1.idp.application.saml.AttributeMappingSpec\x12l\n\x15group_claims_settings\x18\t \x01(\x0b\x32M.yandex.cloud.organizationmanager.v1.idp.application.saml.GroupClaimsSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x19UpdateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"@\n\x18\x44\x65leteApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x19\x44\x65leteApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"A\n\x19SuspendApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x1aSuspendApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"D\n\x1cReactivateApplicationRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x1dReactivateApplicationMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t\"%\n#ListSupportedAttributeValuesRequest\"\x9d\x01\n$ListSupportedAttributeValuesResponse\x12u\n\x1asupported_attribute_values\x18\x01 \x03(\x0b\x32Q.yandex.cloud.organizationmanager.v1.idp.application.saml.SupportedAttributeValue\"(\n\x17SupportedAttributeValue\x12\r\n\x05value\x18\x01 \x01(\t\"\x83\x01\n ListApplicationOperationsRequest\x12 \n\x0e\x61pplication_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"s\n!ListApplicationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"/\n\nAssignment\x12!\n\nsubject_id\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\"\xd3\x01\n\x0f\x41ssignmentDelta\x12`\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32J.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentActionB\x04\xe8\xc7\x31\x01\x12^\n\nassignment\x18\x02 \x01(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentB\x04\xe8\xc7\x31\x01\"\x81\x01\n\x19UpdateAssignmentsResponse\x12\x64\n\x11\x61ssignment_deltas\x18\x01 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentDelta\"}\n\x16ListAssignmentsRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x8d\x01\n\x17ListAssignmentsResponse\x12Y\n\x0b\x61ssignments\x18\x01 \x03(\x0b\x32\x44.yandex.cloud.organizationmanager.v1.idp.application.saml.Assignment\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb2\x01\n\x18UpdateAssignmentsRequest\x12$\n\x0e\x61pplication_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12p\n\x11\x61ssignment_deltas\x18\x02 \x03(\x0b\x32I.yandex.cloud.organizationmanager.v1.idp.application.saml.AssignmentDeltaB\n\x82\xc8\x31\x06\x31-1000\"3\n\x19UpdateAssignmentsMetadata\x12\x16\n\x0e\x61pplication_id\x18\x01 \x01(\t*J\n\x10\x41ssignmentAction\x12!\n\x1d\x41SSIGNMENT_ACTION_UNSPECIFIED\x10\x00\x12\x07\n\x03\x41\x44\x44\x10\x01\x12\n\n\x06REMOVE\x10\x02\x32\x95\x1e\n\x12\x41pplicationService\x12\xf2\x01\n\x03Get\x12O.yandex.cloud.organizationmanager.v1.idp.application.saml.GetApplicationRequest\x1a\x45.yandex.cloud.organizationmanager.v1.idp.application.saml.Application\"S\x82\xd3\xe4\x93\x02M\x12K/organization-manager/v1/idp/application/saml/applications/{application_id}\x12\xf1\x01\n\x04List\x12Q.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationsRequest\x1aR.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationsResponse\"B\x82\xd3\xe4\x93\x02<\x12:/organization-manager/v1/idp/application/saml/applications\x12\xf2\x01\n\x06\x43reate\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.CreateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2*(\n\x19\x43reateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02?\":/organization-manager/v1/idp/application/saml/applications:\x01*\x12\x84\x02\n\x06Update\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x82\x01\xb2\xd2*(\n\x19UpdateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02P2K/organization-manager/v1/idp/application/saml/applications/{application_id}:\x01*\x12\x8b\x02\n\x06\x44\x65lete\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.DeleteApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x89\x01\xb2\xd2*2\n\x19\x44\x65leteApplicationMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02M*K/organization-manager/v1/idp/application/saml/applications/{application_id}\x12\x8f\x02\n\x07Suspend\x12S.yandex.cloud.organizationmanager.v1.idp.application.saml.SuspendApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x8b\x01\xb2\xd2*)\n\x1aSuspendApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02X\"S/organization-manager/v1/idp/application/saml/applications/{application_id}:suspend:\x01*\x12\x9b\x02\n\nReactivate\x12V.yandex.cloud.organizationmanager.v1.idp.application.saml.ReactivateApplicationRequest\x1a!.yandex.cloud.operation.Operation\"\x91\x01\xb2\xd2*,\n\x1dReactivateApplicationMetadata\x12\x0b\x41pplication\x82\xd3\xe4\x93\x02[\"V/organization-manager/v1/idp/application/saml/applications/{application_id}:reactivate:\x01*\x12\xbe\x02\n\x1cListSupportedAttributeValues\x12].yandex.cloud.organizationmanager.v1.idp.application.saml.ListSupportedAttributeValuesRequest\x1a^.yandex.cloud.organizationmanager.v1.idp.application.saml.ListSupportedAttributeValuesResponse\"_\x82\xd3\xe4\x93\x02Y\x12W/organization-manager/v1/idp/application/saml/applications:listSupportedAttributeValues\x12\xa9\x02\n\x0eListOperations\x12Z.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationOperationsRequest\x1a[.yandex.cloud.organizationmanager.v1.idp.application.saml.ListApplicationOperationsResponse\"^\x82\xd3\xe4\x93\x02X\x12V/organization-manager/v1/idp/application/saml/applications/{application_id}/operations\x12\xda\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"c\x82\xd3\xe4\x93\x02]\x12[/organization-manager/v1/idp/application/saml/applications/{resource_id}:listAccessBindings\x12\x99\x02\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xb1\x01\xb2\xd2*H\n access.SetAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02_\"Z/organization-manager/v1/idp/application/saml/applications/{resource_id}:setAccessBindings:\x01*\x12\xa5\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\xb7\x01\xb2\xd2*K\n#access.UpdateAccessBindingsMetadata\x12$access.AccessBindingsOperationResult\x82\xd3\xe4\x93\x02\x62\x32]/organization-manager/v1/idp/application/saml/applications/{resource_id}:updateAccessBindings:\x01*\x12\x9b\x02\n\x0fListAssignments\x12P.yandex.cloud.organizationmanager.v1.idp.application.saml.ListAssignmentsRequest\x1aQ.yandex.cloud.organizationmanager.v1.idp.application.saml.ListAssignmentsResponse\"c\x82\xd3\xe4\x93\x02]\x12[/organization-manager/v1/idp/application/saml/applications/{application_id}:listAssignments\x12\xaf\x02\n\x11UpdateAssignments\x12R.yandex.cloud.organizationmanager.v1.idp.application.saml.UpdateAssignmentsRequest\x1a!.yandex.cloud.operation.Operation\"\xa2\x01\xb2\xd2*6\n\x19UpdateAssignmentsMetadata\x12\x19UpdateAssignmentsResponse\x82\xd3\xe4\x93\x02\x62\x32]/organization-manager/v1/idp/application/saml/applications/{application_id}:updateAssignments:\x01*B\xa1\x01\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;samlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.idp.application.saml.application_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n<yandex.cloud.api.organizationmanager.v1.idp.application.samlZagithub.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1/idp/application/saml;saml'
  _globals['_GETAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_GETAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['filter']._loaded_options = None
  _globals['_LISTAPPLICATIONSREQUEST'].fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['organization_id']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\037[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_CREATEAPPLICATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_NAMEIDSPEC'].fields_by_name['format']._loaded_options = None
  _globals['_NAMEIDSPEC'].fields_by_name['format']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['name_id']._loaded_options = None
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['name_id']._serialized_options = b'\350\3071\001'
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['attributes']._loaded_options = None
  _globals['_ATTRIBUTEMAPPINGSPEC'].fields_by_name['attributes']._serialized_options = b'\202\3101\004<=50'
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['name']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['description']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['labels']._loaded_options = None
  _globals['_UPDATEAPPLICATIONREQUEST'].fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _globals['_DELETEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_DELETEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_SUSPENDAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_SUSPENDAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_REACTIVATEAPPLICATIONREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_REACTIVATEAPPLICATIONREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['application_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_ASSIGNMENT'].fields_by_name['subject_id']._loaded_options = None
  _globals['_ASSIGNMENT'].fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_ASSIGNMENTDELTA'].fields_by_name['action']._loaded_options = None
  _globals['_ASSIGNMENTDELTA'].fields_by_name['action']._serialized_options = b'\350\3071\001'
  _globals['_ASSIGNMENTDELTA'].fields_by_name['assignment']._loaded_options = None
  _globals['_ASSIGNMENTDELTA'].fields_by_name['assignment']._serialized_options = b'\350\3071\001'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_size']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_token']._loaded_options = None
  _globals['_LISTASSIGNMENTSREQUEST'].fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['application_id']._loaded_options = None
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['application_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['assignment_deltas']._loaded_options = None
  _globals['_UPDATEASSIGNMENTSREQUEST'].fields_by_name['assignment_deltas']._serialized_options = b'\202\3101\0061-1000'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Get']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Get']._serialized_options = b'\202\323\344\223\002M\022K/organization-manager/v1/idp/application/saml/applications/{application_id}'
  _globals['_APPLICATIONSERVICE'].methods_by_name['List']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['List']._serialized_options = b'\202\323\344\223\002<\022:/organization-manager/v1/idp/application/saml/applications'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Create']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Create']._serialized_options = b'\262\322*(\n\031CreateApplicationMetadata\022\013Application\202\323\344\223\002?\":/organization-manager/v1/idp/application/saml/applications:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Update']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Update']._serialized_options = b'\262\322*(\n\031UpdateApplicationMetadata\022\013Application\202\323\344\223\002P2K/organization-manager/v1/idp/application/saml/applications/{application_id}:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Delete']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Delete']._serialized_options = b'\262\322*2\n\031DeleteApplicationMetadata\022\025google.protobuf.Empty\202\323\344\223\002M*K/organization-manager/v1/idp/application/saml/applications/{application_id}'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Suspend']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Suspend']._serialized_options = b'\262\322*)\n\032SuspendApplicationMetadata\022\013Application\202\323\344\223\002X\"S/organization-manager/v1/idp/application/saml/applications/{application_id}:suspend:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['Reactivate']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['Reactivate']._serialized_options = b'\262\322*,\n\035ReactivateApplicationMetadata\022\013Application\202\323\344\223\002[\"V/organization-manager/v1/idp/application/saml/applications/{application_id}:reactivate:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListSupportedAttributeValues']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListSupportedAttributeValues']._serialized_options = b'\202\323\344\223\002Y\022W/organization-manager/v1/idp/application/saml/applications:listSupportedAttributeValues'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListOperations']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002X\022V/organization-manager/v1/idp/application/saml/applications/{application_id}/operations'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002]\022[/organization-manager/v1/idp/application/saml/applications/{resource_id}:listAccessBindings'
  _globals['_APPLICATIONSERVICE'].methods_by_name['SetAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*H\n access.SetAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002_\"Z/organization-manager/v1/idp/application/saml/applications/{resource_id}:setAccessBindings:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAccessBindings']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*K\n#access.UpdateAccessBindingsMetadata\022$access.AccessBindingsOperationResult\202\323\344\223\002b2]/organization-manager/v1/idp/application/saml/applications/{resource_id}:updateAccessBindings:\001*'
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAssignments']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['ListAssignments']._serialized_options = b'\202\323\344\223\002]\022[/organization-manager/v1/idp/application/saml/applications/{application_id}:listAssignments'
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAssignments']._loaded_options = None
  _globals['_APPLICATIONSERVICE'].methods_by_name['UpdateAssignments']._serialized_options = b'\262\322*6\n\031UpdateAssignmentsMetadata\022\031UpdateAssignmentsResponse\202\323\344\223\002b2]/organization-manager/v1/idp/application/saml/applications/{application_id}:updateAssignments:\001*'
  _globals['_ASSIGNMENTACTION']._serialized_start=4764
  _globals['_ASSIGNMENTACTION']._serialized_end=4838
  _globals['_GETAPPLICATIONREQUEST']._serialized_start=423
  _globals['_GETAPPLICATIONREQUEST']._serialized_end=484
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=487
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=642
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=645
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=789
  _globals['_CREATEAPPLICATIONREQUEST']._serialized_start=792
  _globals['_CREATEAPPLICATIONREQUEST']._serialized_end=1590
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_start=1545
  _globals['_CREATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_end=1590
  _globals['_SECURITYSETTINGSSPEC']._serialized_start=1593
  _globals['_SECURITYSETTINGSSPEC']._serialized_end=1729
  _globals['_NAMEIDSPEC']._serialized_start=1731
  _globals['_NAMEIDSPEC']._serialized_end=1838
  _globals['_ATTRIBUTEMAPPINGSPEC']._serialized_start=1841
  _globals['_ATTRIBUTEMAPPINGSPEC']._serialized_end=2055
  _globals['_CREATEAPPLICATIONMETADATA']._serialized_start=2057
  _globals['_CREATEAPPLICATIONMETADATA']._serialized_end=2108
  _globals['_UPDATEAPPLICATIONREQUEST']._serialized_start=2111
  _globals['_UPDATEAPPLICATIONREQUEST']._serialized_end=2950
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_start=1545
  _globals['_UPDATEAPPLICATIONREQUEST_LABELSENTRY']._serialized_end=1590
  _globals['_UPDATEAPPLICATIONMETADATA']._serialized_start=2952
  _globals['_UPDATEAPPLICATIONMETADATA']._serialized_end=3003
  _globals['_DELETEAPPLICATIONREQUEST']._serialized_start=3005
  _globals['_DELETEAPPLICATIONREQUEST']._serialized_end=3069
  _globals['_DELETEAPPLICATIONMETADATA']._serialized_start=3071
  _globals['_DELETEAPPLICATIONMETADATA']._serialized_end=3122
  _globals['_SUSPENDAPPLICATIONREQUEST']._serialized_start=3124
  _globals['_SUSPENDAPPLICATIONREQUEST']._serialized_end=3189
  _globals['_SUSPENDAPPLICATIONMETADATA']._serialized_start=3191
  _globals['_SUSPENDAPPLICATIONMETADATA']._serialized_end=3243
  _globals['_REACTIVATEAPPLICATIONREQUEST']._serialized_start=3245
  _globals['_REACTIVATEAPPLICATIONREQUEST']._serialized_end=3313
  _globals['_REACTIVATEAPPLICATIONMETADATA']._serialized_start=3315
  _globals['_REACTIVATEAPPLICATIONMETADATA']._serialized_end=3370
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESREQUEST']._serialized_start=3372
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESREQUEST']._serialized_end=3409
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESRESPONSE']._serialized_start=3412
  _globals['_LISTSUPPORTEDATTRIBUTEVALUESRESPONSE']._serialized_end=3569
  _globals['_SUPPORTEDATTRIBUTEVALUE']._serialized_start=3571
  _globals['_SUPPORTEDATTRIBUTEVALUE']._serialized_end=3611
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST']._serialized_start=3614
  _globals['_LISTAPPLICATIONOPERATIONSREQUEST']._serialized_end=3745
  _globals['_LISTAPPLICATIONOPERATIONSRESPONSE']._serialized_start=3747
  _globals['_LISTAPPLICATIONOPERATIONSRESPONSE']._serialized_end=3862
  _globals['_ASSIGNMENT']._serialized_start=3864
  _globals['_ASSIGNMENT']._serialized_end=3911
  _globals['_ASSIGNMENTDELTA']._serialized_start=3914
  _globals['_ASSIGNMENTDELTA']._serialized_end=4125
  _globals['_UPDATEASSIGNMENTSRESPONSE']._serialized_start=4128
  _globals['_UPDATEASSIGNMENTSRESPONSE']._serialized_end=4257
  _globals['_LISTASSIGNMENTSREQUEST']._serialized_start=4259
  _globals['_LISTASSIGNMENTSREQUEST']._serialized_end=4384
  _globals['_LISTASSIGNMENTSRESPONSE']._serialized_start=4387
  _globals['_LISTASSIGNMENTSRESPONSE']._serialized_end=4528
  _globals['_UPDATEASSIGNMENTSREQUEST']._serialized_start=4531
  _globals['_UPDATEASSIGNMENTSREQUEST']._serialized_end=4709
  _globals['_UPDATEASSIGNMENTSMETADATA']._serialized_start=4711
  _globals['_UPDATEASSIGNMENTSMETADATA']._serialized_end=4762
  _globals['_APPLICATIONSERVICE']._serialized_start=4841
  _globals['_APPLICATIONSERVICE']._serialized_end=8702
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/searchapi/v2/wordstat_service.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/searchapi/v2/wordstat_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/searchapi/v2/wordstat_service.proto\x12\x19yandex.cloud.searchapi.v2\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc5\x01\n\rGetTopRequest\x12\x1d\n\x06phrase\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=400\x12\x1f\n\x0bnum_phrases\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x31-2000\x12\x1a\n\x07regions\x18\x03 \x03(\tB\t\x82\xc8\x31\x05<=100\x12;\n\x07\x64\x65vices\x18\x04 \x03(\x0e\x32!.yandex.cloud.searchapi.v2.DeviceB\x07\x82\xc8\x31\x03<=3\x12\x1b\n\tfolder_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\xe5\x01\n\x0eGetTopResponse\x12\x13\n\x0btotal_count\x18\x01 \x01(\x03\x12\x45\n\x07results\x18\x02 \x03(\x0b\x32\x34.yandex.cloud.searchapi.v2.GetTopResponse.PhraseInfo\x12J\n\x0c\x61ssociations\x18\x03 \x03(\x0b\x32\x34.yandex.cloud.searchapi.v2.GetTopResponse.PhraseInfo\x1a+\n\nPhraseInfo\x12\x0e\n\x06phrase\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"\xb2\x03\n\x12GetDynamicsRequest\x12\x1d\n\x06phrase\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=400\x12J\n\x06period\x18\x02 \x01(\x0e\x32\x34.yandex.cloud.searchapi.v2.GetDynamicsRequest.PeriodB\x04\xe8\xc7\x31\x01\x12\x33\n\tfrom_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe8\xc7\x31\x01\x12+\n\x07to_date\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x07regions\x18\x05 \x03(\tB\t\x82\xc8\x31\x05<=100\x12;\n\x07\x64\x65vices\x18\x06 \x03(\x0e\x32!.yandex.cloud.searchapi.v2.DeviceB\x07\x82\xc8\x31\x03<=3\x12\x1b\n\tfolder_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"Y\n\x06Period\x12\x16\n\x12PERIOD_UNSPECIFIED\x10\x00\x12\x12\n\x0ePERIOD_MONTHLY\x10\x01\x12\x11\n\rPERIOD_WEEKLY\x10\x02\x12\x10\n\x0cPERIOD_DAILY\x10\x03\"\xbb\x01\n\x13GetDynamicsResponse\x12L\n\x07results\x18\x01 \x03(\x0b\x32;.yandex.cloud.searchapi.v2.GetDynamicsResponse.DynamicsInfo\x1aV\n\x0c\x44ynamicsInfo\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\r\n\x05share\x18\x03 \x01(\x01\"\xb9\x02\n\x1dGetRegionsDistributionRequest\x12\x1d\n\x06phrase\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=400\x12O\n\x06region\x18\x02 \x01(\x0e\x32?.yandex.cloud.searchapi.v2.GetRegionsDistributionRequest.Region\x12\x32\n\x07\x64\x65vices\x18\x03 \x03(\x0e\x32!.yandex.cloud.searchapi.v2.Device\x12\x1b\n\tfolder_id\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"W\n\x06Region\x12\x16\n\x12REGION_UNSPECIFIED\x10\x00\x12\x0e\n\nREGION_ALL\x10\x01\x12\x11\n\rREGION_CITIES\x10\x02\x12\x12\n\x0eREGION_REGIONS\x10\x03\"\xcb\x01\n\x1eGetRegionsDistributionResponse\x12U\n\x07results\x18\x01 \x03(\x0b\x32\x44.yandex.cloud.searchapi.v2.GetRegionsDistributionResponse.RegionInfo\x1aR\n\nRegionInfo\x12\x0e\n\x06region\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\x12\r\n\x05share\x18\x03 \x01(\x01\x12\x16\n\x0e\x61\x66\x66inity_index\x18\x04 \x01(\x01\"*\n\x15GetRegionsTreeRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"\xe0\x01\n\x16GetRegionsTreeResponse\x12M\n\x07regions\x18\x01 \x03(\x0b\x32<.yandex.cloud.searchapi.v2.GetRegionsTreeResponse.RegionInfo\x1aw\n\nRegionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t\x12N\n\x08\x63hildren\x18\x03 \x03(\x0b\x32<.yandex.cloud.searchapi.v2.GetRegionsTreeResponse.RegionInfo*i\n\x06\x44\x65vice\x12\x16\n\x12\x44\x45VICE_UNSPECIFIED\x10\x00\x12\x0e\n\nDEVICE_ALL\x10\x01\x12\x12\n\x0e\x44\x45VICE_DESKTOP\x10\x02\x12\x10\n\x0c\x44\x45VICE_PHONE\x10\x03\x12\x11\n\rDEVICE_TABLET\x10\x04\x32\xf8\x04\n\x0fWordstatService\x12\x82\x01\n\x06GetTop\x12(.yandex.cloud.searchapi.v2.GetTopRequest\x1a).yandex.cloud.searchapi.v2.GetTopResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v2/wordstat/topRequests:\x01*\x12\x8e\x01\n\x0bGetDynamics\x12-.yandex.cloud.searchapi.v2.GetDynamicsRequest\x1a..yandex.cloud.searchapi.v2.GetDynamicsResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/v2/wordstat/dynamics:\x01*\x12\xae\x01\n\x16GetRegionsDistribution\x12\x38.yandex.cloud.searchapi.v2.GetRegionsDistributionRequest\x1a\x39.yandex.cloud.searchapi.v2.GetRegionsDistributionResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/v2/wordstat/regions:\x01*\x12\x9d\x01\n\x0eGetRegionsTree\x12\x30.yandex.cloud.searchapi.v2.GetRegionsTreeRequest\x1a\x31.yandex.cloud.searchapi.v2.GetRegionsTreeResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/v2/wordstat/getRegionsTree:\x01*Be\n\x1ayandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapib\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.searchapi.v2.wordstat_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032yandex.cloud.api.search.v2ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/searchapi/v2;searchapi'
  _globals['_GETTOPREQUEST'].fields_by_name['phrase']._loaded_options = None
  _globals['_GETTOPREQUEST'].fields_by_name['phrase']._serialized_options = b'\350\3071\001\212\3101\005<=400'
  _globals['_GETTOPREQUEST'].fields_by_name['num_phrases']._loaded_options = None
  _globals['_GETTOPREQUEST'].fields_by_name['num_phrases']._serialized_options = b'\372\3071\0061-2000'
  _globals['_GETTOPREQUEST'].fields_by_name['regions']._loaded_options = None
  _globals['_GETTOPREQUEST'].fields_by_name['regions']._serialized_options = b'\202\3101\005<=100'
  _globals['_GETTOPREQUEST'].fields_by_name['devices']._loaded_options = None
  _globals['_GETTOPREQUEST'].fields_by_name['devices']._serialized_options = b'\202\3101\003<=3'
  _globals['_GETTOPREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETTOPREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['phrase']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['phrase']._serialized_options = b'\350\3071\001\212\3101\005<=400'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['period']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['period']._serialized_options = b'\350\3071\001'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['from_date']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['from_date']._serialized_options = b'\350\3071\001'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['regions']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['regions']._serialized_options = b'\202\3101\005<=100'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['devices']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['devices']._serialized_options = b'\202\3101\003<=3'
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETDYNAMICSREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_GETREGIONSDISTRIBUTIONREQUEST'].fields_by_name['phrase']._loaded_options = None
  _globals['_GETREGIONSDISTRIBUTIONREQUEST'].fields_by_name['phrase']._serialized_options = b'\350\3071\001\212\3101\005<=400'
  _globals['_GETREGIONSDISTRIBUTIONREQUEST'].fields_by_name['folder_id']._loaded_options = None
  _globals['_GETREGIONSDISTRIBUTIONREQUEST'].fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _globals['_WORDSTATSERVICE'].methods_by_name['GetTop']._loaded_options = None
  _globals['_WORDSTATSERVICE'].methods_by_name['GetTop']._serialized_options = b'\202\323\344\223\002\035\"\030/v2/wordstat/topRequests:\001*'
  _globals['_WORDSTATSERVICE'].methods_by_name['GetDynamics']._loaded_options = None
  _globals['_WORDSTATSERVICE'].methods_by_name['GetDynamics']._serialized_options = b'\202\323\344\223\002\032\"\025/v2/wordstat/dynamics:\001*'
  _globals['_WORDSTATSERVICE'].methods_by_name['GetRegionsDistribution']._loaded_options = None
  _globals['_WORDSTATSERVICE'].methods_by_name['GetRegionsDistribution']._serialized_options = b'\202\323\344\223\002\031\"\024/v2/wordstat/regions:\001*'
  _globals['_WORDSTATSERVICE'].methods_by_name['GetRegionsTree']._loaded_options = None
  _globals['_WORDSTATSERVICE'].methods_by_name['GetRegionsTree']._serialized_options = b'\202\323\344\223\002 \"\033/v2/wordstat/getRegionsTree:\001*'
  _globals['_DEVICE']._serialized_start=2025
  _globals['_DEVICE']._serialized_end=2130
  _globals['_GETTOPREQUEST']._serialized_start=174
  _globals['_GETTOPREQUEST']._serialized_end=371
  _globals['_GETTOPRESPONSE']._serialized_start=374
  _globals['_GETTOPRESPONSE']._serialized_end=603
  _globals['_GETTOPRESPONSE_PHRASEINFO']._serialized_start=560
  _globals['_GETTOPRESPONSE_PHRASEINFO']._serialized_end=603
  _globals['_GETDYNAMICSREQUEST']._serialized_start=606
  _globals['_GETDYNAMICSREQUEST']._serialized_end=1040
  _globals['_GETDYNAMICSREQUEST_PERIOD']._serialized_start=951
  _globals['_GETDYNAMICSREQUEST_PERIOD']._serialized_end=1040
  _globals['_GETDYNAMICSRESPONSE']._serialized_start=1043
  _globals['_GETDYNAMICSRESPONSE']._serialized_end=1230
  _globals['_GETDYNAMICSRESPONSE_DYNAMICSINFO']._serialized_start=1144
  _globals['_GETDYNAMICSRESPONSE_DYNAMICSINFO']._serialized_end=1230
  _globals['_GETREGIONSDISTRIBUTIONREQUEST']._serialized_start=1233
  _globals['_GETREGIONSDISTRIBUTIONREQUEST']._serialized_end=1546
  _globals['_GETREGIONSDISTRIBUTIONREQUEST_REGION']._serialized_start=1459
  _globals['_GETREGIONSDISTRIBUTIONREQUEST_REGION']._serialized_end=1546
  _globals['_GETREGIONSDISTRIBUTIONRESPONSE']._serialized_start=1549
  _globals['_GETREGIONSDISTRIBUTIONRESPONSE']._serialized_end=1752
  _globals['_GETREGIONSDISTRIBUTIONRESPONSE_REGIONINFO']._serialized_start=1670
  _globals['_GETREGIONSDISTRIBUTIONRESPONSE_REGIONINFO']._serialized_end=1752
  _globals['_GETREGIONSTREEREQUEST']._serialized_start=1754
  _globals['_GETREGIONSTREEREQUEST']._serialized_end=1796
  _globals['_GETREGIONSTREERESPONSE']._serialized_start=1799
  _globals['_GETREGIONSTREERESPONSE']._serialized_end=2023
  _globals['_GETREGIONSTREERESPONSE_REGIONINFO']._serialized_start=1904
  _globals['_GETREGIONSTREERESPONSE_REGIONINFO']._serialized_end=2023
  _globals['_WORDSTATSERVICE']._serialized_start=2133
  _globals['_WORDSTATSERVICE']._serialized_end=2765
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/billing/usage_records/v1/common_types.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/billing/usage_records/v1/common_types.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/billing/usage_records/v1/common_types.proto\x12%yandex.cloud.billing.usage_records.v1\"\x1e\n\rStringDecimal\x12\r\n\x05value\x18\x01 \x01(\t*b\n\x0cTimeGrouping\x12\x1d\n\x19TIME_GROUPING_UNSPECIFIED\x10\x00\x12\x07\n\x03\x44\x41Y\x10\x01\x12\x08\n\x04WEEK\x10\x02\x12\t\n\x05MONTH\x10\x03\x12\x0b\n\x07QUARTER\x10\x04\x12\x08\n\x04YEAR\x10\x05*H\n\x08\x43urrency\x12\x18\n\x14\x43URRENCY_UNSPECIFIED\x10\x00\x12\x07\n\x03RUB\x10\x01\x12\x07\n\x03USD\x10\x02\x12\x07\n\x03KZT\x10\x03\x12\x07\n\x03\x45UR\x10\x04\x42\x83\x01\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecordsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.usage_records.v1.common_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n)yandex.cloud.api.billing.usage_records.v1ZVgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/usage_records/v1;usageRecords'
  _globals['_TIMEGROUPING']._serialized_start=131
  _globals['_TIMEGROUPING']._serialized_end=229
  _globals['_CURRENCY']._serialized_start=231
  _globals['_CURRENCY']._serialized_end=303
  _globals['_STRINGDECIMAL']._serialized_start=99
  _globals['_STRINGDECIMAL']._serialized_end=129
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cdn/v1/resource.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cdn/v1/resource.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"yandex/cloud/cdn/v1/resource.proto\x12\x13yandex.cloud.cdn.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"$\n\x12SecondaryHostnames\x12\x0e\n\x06values\x18\x01 \x03(\t\"\xec\x04\n\x08Resource\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\r\n\x05\x63name\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\x06 \x01(\x08\x12\x35\n\x07options\x18\x07 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptions\x12\x1b\n\x13secondary_hostnames\x18\x08 \x03(\t\x12\x17\n\x0forigin_group_id\x18\t \x01(\x03\x12\x19\n\x11origin_group_name\x18\n \x01(\t\x12<\n\x0forigin_protocol\x18\x0b \x01(\x0e\x32#.yandex.cloud.cdn.v1.OriginProtocol\x12<\n\x0fssl_certificate\x18\x0c \x01(\x0b\x32#.yandex.cloud.cdn.v1.SSLCertificate\x12\x39\n\x06labels\x18\r \x03(\x0b\x32).yandex.cloud.cdn.v1.Resource.LabelsEntry\x12\x15\n\rprovider_type\x18\x0e \x01(\t\x12\x16\n\x0eprovider_cname\x18\x0f \x01(\t\x12%\n\x03tls\x18\x10 \x01(\x0b\x32\x18.yandex.cloud.cdn.v1.TLS\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2(\n\x0fResourceOptions\x12\x46\n\rdisable_cache\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12S\n\x13\x65\x64ge_cache_settings\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.EdgeCacheSettings\x12P\n\x16\x62rowser_cache_settings\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.cdn.v1.ResourceOptions.Int64Option\x12R\n\x12\x63\x61\x63he_http_headers\x18\x04 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12U\n\x14query_params_options\x18\x05 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.QueryParamsOptions\x12>\n\x05slice\x18\x06 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12T\n\x13\x63ompression_options\x18\x07 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.CompressionOptions\x12N\n\x10redirect_options\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.cdn.v1.ResourceOptions.RedirectOptions\x12\x46\n\x0chost_options\x18\t \x01(\x0b\x32\x30.yandex.cloud.cdn.v1.ResourceOptions.HostOptions\x12M\n\x0estatic_headers\x18\n \x01(\x0b\x32\x35.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption\x12\x44\n\x04\x63ors\x18\x0b \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12\x45\n\x05stale\x18\x0c \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12T\n\x14\x61llowed_http_methods\x18\r \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOption\x12P\n\x17proxy_cache_methods_set\x18\x0e \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12S\n\x1a\x64isable_proxy_force_ranges\x18\x0f \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12U\n\x16static_request_headers\x18\x10 \x01(\x0b\x32\x35.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption\x12M\n\x12\x63ustom_server_name\x18\x11 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOption\x12\x46\n\rignore_cookie\x18\x12 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOption\x12\x43\n\x07rewrite\x18\x13 \x01(\x0b\x32\x32.yandex.cloud.cdn.v1.ResourceOptions.RewriteOption\x12H\n\nsecure_key\x18\x14 \x01(\x0b\x32\x34.yandex.cloud.cdn.v1.ResourceOptions.SecureKeyOption\x12O\n\x0eip_address_acl\x18\x15 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.IPAddressACLOption\x12T\n\x10\x66ollow_redirects\x18\x16 \x01(\x0b\x32:.yandex.cloud.cdn.v1.ResourceOptions.FollowRedirectsOption\x12I\n\nwebsockets\x18\x17 \x01(\x0b\x32\x35.yandex.cloud.cdn.v1.ResourceOptions.WebsocketsOption\x12N\n\rheader_filter\x18\x18 \x01(\x0b\x32\x37.yandex.cloud.cdn.v1.ResourceOptions.HeaderFilterOption\x12\x42\n\x07geo_acl\x18\x19 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.GeoACLOption\x12L\n\x0creferrer_acl\x18\x1a \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.ReferrerACLOption\x12R\n\x0fstatic_response\x18\x1b \x01(\x0b\x32\x39.yandex.cloud.cdn.v1.ResourceOptions.StaticResponseOption\x1a,\n\nBoolOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x08\x1a.\n\x0cStringOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\t\x1a-\n\x0bInt64Option\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x01(\x03\x1a\x33\n\x11StringsListOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05value\x18\x02 \x03(\t\x1a\xa2\x01\n\x10StringsMapOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12O\n\x05value\x18\x02 \x03(\x0b\x32@.yandex.cloud.cdn.v1.ResourceOptions.StringsMapOption.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xb5\x01\n\x0c\x43\x61\x63hingTimes\x12\x14\n\x0csimple_value\x18\x01 \x01(\x03\x12Z\n\rcustom_values\x18\x02 \x03(\x0b\x32\x43.yandex.cloud.cdn.v1.ResourceOptions.CachingTimes.CustomValuesEntry\x1a\x33\n\x11\x43ustomValuesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x93\x01\n\x11\x45\x64geCacheSettings\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x42\n\x05value\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.CachingTimesH\x00\x12\x17\n\rdefault_value\x18\x03 \x01(\x03H\x00\x42\x10\n\x0evalues_variant\x1a\xa9\x03\n\x17StringVariableMapOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12V\n\x05value\x18\x02 \x03(\x0b\x32G.yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.ValueEntry\x1a\xac\x01\n\x0bOneofString\x12\x42\n\x05value\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOptionH\x00\x12H\n\x06values\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x0f\n\rstring_option\x1av\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12W\n\x05value\x18\x02 \x01(\x0b\x32H.yandex.cloud.cdn.v1.ResourceOptions.StringVariableMapOption.OneofString:\x02\x38\x01\x1a\xb0\x02\n\x12QueryParamsOptions\x12N\n\x13ignore_query_string\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12X\n\x16query_params_whitelist\x18\x02 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x12X\n\x16query_params_blacklist\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x16\n\x14query_params_variant\x1a\xcf\x01\n\x0fRedirectOptions\x12Q\n\x16redirect_http_to_https\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12U\n\x16redirect_https_to_http\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionB\x02\x18\x01H\x00\x42\x12\n\x10redirect_variant\x1a\xb0\x01\n\x0bHostOptions\x12\x41\n\x04host\x18\x01 \x01(\x0b\x32\x31.yandex.cloud.cdn.v1.ResourceOptions.StringOptionH\x00\x12N\n\x13\x66orward_host_header\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x42\x0e\n\x0chost_variant\x1a\x92\x02\n\x12\x43ompressionOptions\x12K\n\x10\x66\x65tch_compressed\x18\x01 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12\x42\n\x07gzip_on\x18\x02 \x01(\x0b\x32/.yandex.cloud.cdn.v1.ResourceOptions.BoolOptionH\x00\x12T\n\x12\x62rotli_compression\x18\x03 \x01(\x0b\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.StringsListOptionH\x00\x42\x15\n\x13\x63ompression_variant\x1a^\n\rRewriteOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t\x12.\n\x04\x66lag\x18\x03 \x01(\x0e\x32 .yandex.cloud.cdn.v1.RewriteFlag\x1a\x64\n\x0fSecureKeyOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x33\n\x04type\x18\x03 \x01(\x0e\x32%.yandex.cloud.cdn.v1.SecureKeyURLType\x1at\n\x12IPAddressACLOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x34\n\x0bpolicy_type\x18\x02 \x01(\x0e\x32\x1f.yandex.cloud.cdn.v1.PolicyType\x12\x17\n\x0f\x65xcepted_values\x18\x03 \x03(\t\x1aP\n\x15\x46ollowRedirectsOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\r\n\x05\x63odes\x18\x02 \x03(\x03\x12\x17\n\x0fuse_custom_host\x18\x03 \x01(\x08\x1a#\n\x10WebsocketsOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x1a\x36\n\x12HeaderFilterOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0f\n\x07headers\x18\x02 \x03(\t\x1a\xb5\x01\n\x0cGeoACLOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x44\n\x04mode\x18\x02 \x01(\x0e\x32\x36.yandex.cloud.cdn.v1.ResourceOptions.GeoACLOption.Mode\x12\x11\n\tcountries\x18\x03 \x03(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nMODE_ALLOW\x10\x01\x12\r\n\tMODE_DENY\x10\x02\x1a\xbf\x01\n\x11ReferrerACLOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12I\n\x04mode\x18\x02 \x01(\x0e\x32;.yandex.cloud.cdn.v1.ResourceOptions.ReferrerACLOption.Mode\x12\x11\n\treferrers\x18\x03 \x03(\t\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nMODE_ALLOW\x10\x01\x12\r\n\tMODE_DENY\x10\x02\x1a\x46\n\x14StaticResponseOption\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x03\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t\"\x84\x01\n\x14SSLTargetCertificate\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.cdn.v1.SSLCertificateType\x12\x35\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SSLCertificateData\"\xb9\x01\n\x0eSSLCertificate\x12\x35\n\x04type\x18\x01 \x01(\x0e\x32\'.yandex.cloud.cdn.v1.SSLCertificateType\x12\x39\n\x06status\x18\x02 \x01(\x0e\x32).yandex.cloud.cdn.v1.SSLCertificateStatus\x12\x35\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\'.yandex.cloud.cdn.v1.SSLCertificateData\"m\n\x12SSLCertificateData\x12\x37\n\x02\x63m\x18\x01 \x01(\x0b\x32).yandex.cloud.cdn.v1.SSLCertificateCMDataH\x00\x42\x1e\n\x1cssl_certificate_data_variant\"\"\n\x14SSLCertificateCMData\x12\n\n\x02id\x18\x01 \x01(\t\"\xb0\x01\n\x03TLS\x12\x31\n\x07profile\x18\x01 \x01(\x0e\x32 .yandex.cloud.cdn.v1.TLS.Profile\"v\n\x07Profile\x12\x17\n\x13PROFILE_UNSPECIFIED\x10\x00\x12\x16\n\x12PROFILE_COMPATIBLE\x10\x01\x12\x12\n\x0ePROFILE_LEGACY\x10\x02\x12\x12\n\x0ePROFILE_SECURE\x10\x03\x12\x12\n\x0ePROFILE_STRICT\x10\x04*Q\n\x0eOriginProtocol\x12\x1f\n\x1bORIGIN_PROTOCOL_UNSPECIFIED\x10\x00\x12\x08\n\x04HTTP\x10\x01\x12\t\n\x05HTTPS\x10\x02\x12\t\n\x05MATCH\x10\x03*]\n\x0bRewriteFlag\x12\x1c\n\x18REWRITE_FLAG_UNSPECIFIED\x10\x00\x12\x08\n\x04LAST\x10\x01\x12\t\n\x05\x42REAK\x10\x02\x12\x0c\n\x08REDIRECT\x10\x03\x12\r\n\tPERMANENT\x10\x04*f\n\x10SecureKeyURLType\x12#\n\x1fSECURE_KEY_URL_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11\x45NABLE_IP_SIGNING\x10\x01\x12\x16\n\x12\x44ISABLE_IP_SIGNING\x10\x02*V\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11POLICY_TYPE_ALLOW\x10\x01\x12\x14\n\x10POLICY_TYPE_DENY\x10\x02*l\n\x12SSLCertificateType\x12$\n SSL_CERTIFICATE_TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ONT_USE\x10\x01\x12\x1a\n\x12LETS_ENCRYPT_GCORE\x10\x02\x1a\x02\x08\x01\x12\x06\n\x02\x43M\x10\x03*[\n\x14SSLCertificateStatus\x12&\n\"SSL_CERTIFICATE_STATUS_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\x01\x12\x10\n\x08\x43REATING\x10\x02\x1a\x02\x08\x01\x42V\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.resource_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _globals['_SSLCERTIFICATETYPE'].values_by_name["LETS_ENCRYPT_GCORE"]._loaded_options = None
  _globals['_SSLCERTIFICATETYPE'].values_by_name["LETS_ENCRYPT_GCORE"]._serialized_options = b'\010\001'
  _globals['_SSLCERTIFICATESTATUS'].values_by_name["CREATING"]._loaded_options = None
  _globals['_SSLCERTIFICATESTATUS'].values_by_name["CREATING"]._serialized_options = b'\010\001'
  _globals['_RESOURCE_LABELSENTRY']._loaded_options = None
  _globals['_RESOURCE_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY']._loaded_options = None
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY']._loaded_options = None
  _globals['_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY']._loaded_options = None
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY']._serialized_options = b'8\001'
  _globals['_RESOURCEOPTIONS_REDIRECTOPTIONS'].fields_by_name['redirect_https_to_http']._loaded_options = None
  _globals['_RESOURCEOPTIONS_REDIRECTOPTIONS'].fields_by_name['redirect_https_to_http']._serialized_options = b'\030\001'
  _globals['_ORIGINPROTOCOL']._serialized_start=6575
  _globals['_ORIGINPROTOCOL']._serialized_end=6656
  _globals['_REWRITEFLAG']._serialized_start=6658
  _globals['_REWRITEFLAG']._serialized_end=6751
  _globals['_SECUREKEYURLTYPE']._serialized_start=6753
  _globals['_SECUREKEYURLTYPE']._serialized_end=6855
  _globals['_POLICYTYPE']._serialized_start=6857
  _globals['_POLICYTYPE']._serialized_end=6943
  _globals['_SSLCERTIFICATETYPE']._serialized_start=6945
  _globals['_SSLCERTIFICATETYPE']._serialized_end=7053
  _globals['_SSLCERTIFICATESTATUS']._serialized_start=7055
  _globals['_SSLCERTIFICATESTATUS']._serialized_end=7146
  _globals['_SECONDARYHOSTNAMES']._serialized_start=92
  _globals['_SECONDARYHOSTNAMES']._serialized_end=128
  _globals['_RESOURCE']._serialized_start=131
  _globals['_RESOURCE']._serialized_end=751
  _globals['_RESOURCE_LABELSENTRY']._serialized_start=706
  _globals['_RESOURCE_LABELSENTRY']._serialized_end=751
  _globals['_RESOURCEOPTIONS']._serialized_start=754
  _globals['_RESOURCEOPTIONS']._serialized_end=5924
  _globals['_RESOURCEOPTIONS_BOOLOPTION']._serialized_start=2891
  _globals['_RESOURCEOPTIONS_BOOLOPTION']._serialized_end=2935
  _globals['_RESOURCEOPTIONS_STRINGOPTION']._serialized_start=2937
  _globals['_RESOURCEOPTIONS_STRINGOPTION']._serialized_end=2983
  _globals['_RESOURCEOPTIONS_INT64OPTION']._serialized_start=2985
  _globals['_RESOURCEOPTIONS_INT64OPTION']._serialized_end=3030
  _globals['_RESOURCEOPTIONS_STRINGSLISTOPTION']._serialized_start=3032
  _globals['_RESOURCEOPTIONS_STRINGSLISTOPTION']._serialized_end=3083
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION']._serialized_start=3086
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION']._serialized_end=3248
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY']._serialized_start=3204
  _globals['_RESOURCEOPTIONS_STRINGSMAPOPTION_VALUEENTRY']._serialized_end=3248
  _globals['_RESOURCEOPTIONS_CACHINGTIMES']._serialized_start=3251
  _globals['_RESOURCEOPTIONS_CACHINGTIMES']._serialized_end=3432
  _globals['_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY']._serialized_start=3381
  _globals['_RESOURCEOPTIONS_CACHINGTIMES_CUSTOMVALUESENTRY']._serialized_end=3432
  _globals['_RESOURCEOPTIONS_EDGECACHESETTINGS']._serialized_start=3435
  _globals['_RESOURCEOPTIONS_EDGECACHESETTINGS']._serialized_end=3582
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION']._serialized_start=3585
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION']._serialized_end=4010
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING']._serialized_start=3718
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_ONEOFSTRING']._serialized_end=3890
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY']._serialized_start=3892
  _globals['_RESOURCEOPTIONS_STRINGVARIABLEMAPOPTION_VALUEENTRY']._serialized_end=4010
  _globals['_RESOURCEOPTIONS_QUERYPARAMSOPTIONS']._serialized_start=4013
  _globals['_RESOURCEOPTIONS_QUERYPARAMSOPTIONS']._serialized_end=4317
  _globals['_RESOURCEOPTIONS_REDIRECTOPTIONS']._serialized_start=4320
  _globals['_RESOURCEOPTIONS_REDIRECTOPTIONS']._serialized_end=4527
  _globals['_RESOURCEOPTIONS_HOSTOPTIONS']._serialized_start=4530
  _globals['_RESOURCEOPTIONS_HOSTOPTIONS']._serialized_end=4706
  _globals['_RESOURCEOPTIONS_COMPRESSIONOPTIONS']._serialized_start=4709
  _globals['_RESOURCEOPTIONS_COMPRESSIONOPTIONS']._serialized_end=4983
  _globals['_RESOURCEOPTIONS_REWRITEOPTION']._serialized_start=4985
  _globals['_RESOURCEOPTIONS_REWRITEOPTION']._serialized_end=5079
  _globals['_RESOURCEOPTIONS_SECUREKEYOPTION']._serialized_start=5081
  _globals['_RESOURCEOPTIONS_SECUREKEYOPTION']._serialized_end=5181
  _globals['_RESOURCEOPTIONS_IPADDRESSACLOPTION']._serialized_start=5183
  _globals['_RESOURCEOPTIONS_IPADDRESSACLOPTION']._serialized_end=5299
  _globals['_RESOURCEOPTIONS_FOLLOWREDIRECTSOPTION']._serialized_start=5301
  _globals['_RESOURCEOPTIONS_FOLLOWREDIRECTSOPTION']._serialized_end=5381
  _globals['_RESOURCEOPTIONS_WEBSOCKETSOPTION']._serialized_start=5383
  _globals['_RESOURCEOPTIONS_WEBSOCKETSOPTION']._serialized_end=5418
  _globals['_RESOURCEOPTIONS_HEADERFILTEROPTION']._serialized_start=5420
  _globals['_RESOURCEOPTIONS_HEADERFILTEROPTION']._serialized_end=5474
  _globals['_RESOURCEOPTIONS_GEOACLOPTION']._serialized_start=5477
  _globals['_RESOURCEOPTIONS_GEOACLOPTION']._serialized_end=5658
  _globals['_RESOURCEOPTIONS_GEOACLOPTION_MODE']._serialized_start=5599
  _globals['_RESOURCEOPTIONS_GEOACLOPTION_MODE']._serialized_end=5658
  _globals['_RESOURCEOPTIONS_REFERRERACLOPTION']._serialized_start=5661
  _globals['_RESOURCEOPTIONS_REFERRERACLOPTION']._serialized_end=5852
  _globals['_RESOURCEOPTIONS_REFERRERACLOPTION_MODE']._serialized_start=5599
  _globals['_RESOURCEOPTIONS_REFERRERACLOPTION_MODE']._serialized_end=5658
  _globals['_RESOURCEOPTIONS_STATICRESPONSEOPTION']._serialized_start=5854
  _globals['_RESOURCEOPTIONS_STATICRESPONSEOPTION']._serialized_end=5924
  _globals['_SSLTARGETCERTIFICATE']._serialized_start=5927
  _globals['_SSLTARGETCERTIFICATE']._serialized_end=6059
  _globals['_SSLCERTIFICATE']._serialized_start=6062
  _globals['_SSLCERTIFICATE']._serialized_end=6247
  _globals['_SSLCERTIFICATEDATA']._serialized_start=6249
  _globals['_SSLCERTIFICATEDATA']._serialized_end=6358
  _globals['_SSLCERTIFICATECMDATA']._serialized_start=6360
  _globals['_SSLCERTIFICATECMDATA']._serialized_end=6394
  _globals['_TLS']._serialized_start=6397
  _globals['_TLS']._serialized_end=6573
  _globals['_TLS_PROFILE']._serialized_start=6455
  _globals['_TLS_PROFILE']._serialized_end=6573
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/cic/v1/peering.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/cic/v1/peering.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!yandex/cloud/cic/v1/peering.proto\x12\x13yandex.cloud.cic.v1\x1a\x1dyandex/cloud/validation.proto\"\xce\x01\n\x07Peering\x12$\n\x0epeering_subnet\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x07peer_ip\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x08\x63loud_ip\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x0cpeer_bgp_asn\x18\x04 \x01(\x03\x42\x04\xe8\xc7\x31\x01\x12\x1d\n\rcloud_bgp_asn\x18\x05 \x01(\x03\x42\x06\x18\x01\xe8\xc7\x31\x01\x12#\n\x10peer_bgp_md5_key\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=200BV\n\x17yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cicb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cic.v1.peering_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027yandex.cloud.api.cic.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cic/v1;cic'
  _globals['_PEERING'].fields_by_name['peering_subnet']._loaded_options = None
  _globals['_PEERING'].fields_by_name['peering_subnet']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PEERING'].fields_by_name['peer_ip']._loaded_options = None
  _globals['_PEERING'].fields_by_name['peer_ip']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PEERING'].fields_by_name['cloud_ip']._loaded_options = None
  _globals['_PEERING'].fields_by_name['cloud_ip']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _globals['_PEERING'].fields_by_name['peer_bgp_asn']._loaded_options = None
  _globals['_PEERING'].fields_by_name['peer_bgp_asn']._serialized_options = b'\350\3071\001'
  _globals['_PEERING'].fields_by_name['cloud_bgp_asn']._loaded_options = None
  _globals['_PEERING'].fields_by_name['cloud_bgp_asn']._serialized_options = b'\030\001\350\3071\001'
  _globals['_PEERING'].fields_by_name['peer_bgp_md5_key']._loaded_options = None
  _globals['_PEERING'].fields_by_name['peer_bgp_md5_key']._serialized_options = b'\212\3101\005<=200'
  _globals['_PEERING']._serialized_start=90
  _globals['_PEERING']._serialized_end=296
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.organizationmanager.v1.saml import federation_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2
from yandex.cloud.organizationmanager.v1.saml import federation_service_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/organizationmanager/v1/saml/federation_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class FederationServiceStub(object):
    """A set of methods for managing federations.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/Get',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Federation.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/List',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/Create',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.CreateFederationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/Update',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.UpdateFederationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/Delete',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.AddUserAccounts = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/AddUserAccounts',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederatedUserAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DeleteUserAccounts = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/DeleteUserAccounts',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederatedUserAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListUserAccounts = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListUserAccounts',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsResponse.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsResponse.FromString,
                _registered_method=True)
        self.GetDomain = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/GetDomain',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Domain.FromString,
                _registered_method=True)
        self.ListDomains = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListDomains',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsResponse.FromString,
                _registered_method=True)
        self.AddDomain = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/AddDomain',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederationDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ValidateDomain = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/ValidateDomain',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ValidateFederationDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.DeleteDomain = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/DeleteDomain',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationDomainRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.SuspendUserAccounts = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/SuspendUserAccounts',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.SuspendFederatedUserAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ReactivateUserAccounts = channel.unary_unary(
                '/yandex.cloud.organizationmanager.v1.saml.FederationService/ReactivateUserAccounts',
                request_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ReactivateFederatedUserAccountsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class FederationServiceServicer(object):
    """A set of methods for managing federations.
    """

    def Get(self, request, context):
        """Returns the specified federation.

        To get the list of available federations, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of federations in the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a federation in the specified organization.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddUserAccounts(self, request, context):
        """Adds users to the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteUserAccounts(self, request, context):
        """Deletes users from the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListUserAccounts(self, request, context):
        """Lists users for the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetDomain(self, request, context):
        """Returns the specified domain in the federation.

        To get the list of available domains, make a [ListDomains] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDomains(self, request, context):
        """Retrieves the list of domains in the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDomain(self, request, context):
        """Adds a domain to the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ValidateDomain(self, request, context):
        """Validates a domain in the specified federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDomain(self, request, context):
        """Deletes the specified domain from the federation.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuspendUserAccounts(self, request, context):
        """Suspend federated user accounts.
        Method skips non-existent federated user accounts and returns ones that were actually suspended.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReactivateUserAccounts(self, request, context):
        """Reactivate federated user accounts.
        Method skips non-existent federated user accounts and returns ones that were actually reactivated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_FederationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Federation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.CreateFederationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.UpdateFederationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.AddUserAccounts,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederatedUserAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteUserAccounts,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederatedUserAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListUserAccounts,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsResponse.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsResponse.SerializeToString,
            ),
            'GetDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.GetDomain,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Domain.SerializeToString,
            ),
            'ListDomains': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDomains,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsResponse.SerializeToString,
            ),
            'AddDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDomain,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederationDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ValidateDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.ValidateDomain,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ValidateFederationDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteDomain': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDomain,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationDomainRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'SuspendUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.SuspendUserAccounts,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.SuspendFederatedUserAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ReactivateUserAccounts': grpc.unary_unary_rpc_method_handler(
                    servicer.ReactivateUserAccounts,
                    request_deserializer=yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ReactivateFederatedUserAccountsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.organizationmanager.v1.saml.FederationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.organizationmanager.v1.saml.FederationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class FederationService(object):
    """A set of methods for managing federations.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/Get',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Federation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/List',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/Create',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.CreateFederationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/Update',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.UpdateFederationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/Delete',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/AddUserAccounts',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederatedUserAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/DeleteUserAccounts',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederatedUserAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListUserAccounts',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederatedUserAccountsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListOperations',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/GetDomain',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.GetFederationDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__pb2.Domain.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDomains(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/ListDomains',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsRequest.SerializeToString,
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ListFederationDomainsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/AddDomain',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.AddFederationDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ValidateDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/ValidateDomain',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ValidateFederationDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DeleteDomain(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/DeleteDomain',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.DeleteFederationDomainRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SuspendUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/SuspendUserAccounts',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.SuspendFederatedUserAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ReactivateUserAccounts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.organizationmanager.v1.saml.FederationService/ReactivateUserAccounts',
            yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_saml_dot_federation__service__pb2.ReactivateFederatedUserAccountsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2
import yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class MfaEnforcementServiceStub:
    """a set of methods for managing MFA enforcements"""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.CreateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """creates an MFA enforcement in the specified organization"""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates the specified MFA enforcement"""

    Activate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ActivateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """activates the specified MFA enforcement"""

    Deactivate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeactivateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """deactivates the specified MFA enforcement"""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeleteMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """deletes the specified MFA enforcement"""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.GetMfaEnforcementRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement,
    ]
    """returns the specified MFA enforcement"""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsResponse,
    ]
    """returns MFA enforcements for the specified organization"""

    UpdateAudience: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateAudienceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates specified MFA enforcement's audience"""

    ListAudience: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceResponse,
    ]
    """returns specified MFA enforcement's audience"""

    UpdateExcludedAudience: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateExcludedAudienceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates specified MFA enforcement's excluded audience"""

    ListExcludedAudience: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceResponse,
    ]
    """returns specified MFA enforcement's excluded audience"""

class MfaEnforcementServiceAsyncStub:
    """a set of methods for managing MFA enforcements"""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.CreateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """creates an MFA enforcement in the specified organization"""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates the specified MFA enforcement"""

    Activate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ActivateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """activates the specified MFA enforcement"""

    Deactivate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeactivateMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """deactivates the specified MFA enforcement"""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeleteMfaEnforcementRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """deletes the specified MFA enforcement"""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.GetMfaEnforcementRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement,
    ]
    """returns the specified MFA enforcement"""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsResponse,
    ]
    """returns MFA enforcements for the specified organization"""

    UpdateAudience: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateAudienceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates specified MFA enforcement's audience"""

    ListAudience: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceResponse,
    ]
    """returns specified MFA enforcement's audience"""

    UpdateExcludedAudience: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateExcludedAudienceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """updates specified MFA enforcement's excluded audience"""

    ListExcludedAudience: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceRequest,
        yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceResponse,
    ]
    """returns specified MFA enforcement's excluded audience"""

class MfaEnforcementServiceServicer(metaclass=abc.ABCMeta):
    """a set of methods for managing MFA enforcements"""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.CreateMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """creates an MFA enforcement in the specified organization"""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """updates the specified MFA enforcement"""

    @abc.abstractmethod
    def Activate(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ActivateMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """activates the specified MFA enforcement"""

    @abc.abstractmethod
    def Deactivate(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeactivateMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """deactivates the specified MFA enforcement"""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.DeleteMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """deletes the specified MFA enforcement"""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.GetMfaEnforcementRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.mfa_enforcement_pb2.MfaEnforcement]]:
        """returns the specified MFA enforcement"""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListMfaEnforcementsResponse]]:
        """returns MFA enforcements for the specified organization"""

    @abc.abstractmethod
    def UpdateAudience(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateAudienceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """updates specified MFA enforcement's audience"""

    @abc.abstractmethod
    def ListAudience(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListAudienceResponse]]:
        """returns specified MFA enforcement's audience"""

    @abc.abstractmethod
    def UpdateExcludedAudience(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.UpdateExcludedAudienceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """updates specified MFA enforcement's excluded audience"""

    @abc.abstractmethod
    def ListExcludedAudience(
        self,
        request: yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.mfa_enforcement_service_pb2.ListExcludedAudienceResponse]]:
        """returns specified MFA enforcement's excluded audience"""

def add_MfaEnforcementServiceServicer_to_server(servicer: MfaEnforcementServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
